@@ -4,16 +4,16 @@
    Copyright (C) 2000 Eazel, Inc.
   
    This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
+   modify it under the terms of the GNU Library General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.
   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
+   Library General Public License for more details.
   
-   You should have received a copy of the GNU General Public
+   You should have received a copy of the GNU Library General Public
    License along with this program; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
@@ -57,16 +57,26 @@ GdkPixbuf  *rsvg_handle_get_pixbuf        (RsvgHandle      *handle);
 void        rsvg_handle_free              (RsvgHandle      *handle);
 
 /* convenience API */
-GdkPixbuf  *rsvg_pixbuf_from_file         (const gchar     *file_name,
- 					   GError         **error);
-GdkPixbuf  *rsvg_pixbuf_from_file_at_zoom (const gchar     *file_name,
-					   double           x_zoom,
-					   double           y_zoom,
- 					   GError         **error);
-GdkPixbuf  *rsvg_pixbuf_from_file_at_size (const gchar     *file_name,
-					   gint             width,
-					   gint             height,
-					   GError         **error);
+GdkPixbuf  *rsvg_pixbuf_from_file                  (const gchar  *file_name,
+						    GError      **error);
+GdkPixbuf  *rsvg_pixbuf_from_file_at_zoom          (const gchar  *file_name,
+						    double        x_zoom,
+						    double        y_zoom,
+						    GError      **error);
+GdkPixbuf  *rsvg_pixbuf_from_file_at_size          (const gchar  *file_name,
+						    gint          width,
+						    gint          height,
+						    GError      **error);
+GdkPixbuf  *rsvg_pixbuf_from_file_at_max_size      (const gchar  *file_name,
+						    gint          max_width,
+						    gint          max_height,
+						    GError      **error);
+GdkPixbuf  *rsvg_pixbuf_from_file_at_zoom_with_max (const gchar  *file_name,
+						    double        x_zoom,
+						    double        y_zoom,
+						    gint          max_width,
+						    gint          max_height,
+						    GError      **error);
 
 
 G_END_DECLS
